@@ -4,9 +4,9 @@ Anything not explicitly documented here should not be used directly by clients a
 only exposed for testing, the CLI, and type hinting.
 """
 
-from importlib_metadata import version
+from importlib.metadata import version
 
-from .core import problem, test_case
+from .core import group, problem, test_case
 
-__all__ = ("problem", "test_case")
+__all__ = ("problem", "test_case", "group")
 __version__ = version(__name__)  # type: ignore
